/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or 1any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer: Paul KEMLER
 * --------------------------------------------------------------------------
 * $Id: JProperties.java,v 1.2 2005/05/19 13:22:39 kemlerp Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.examples.clients.jonasadmin.util;

import java.util.Properties;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.objectweb.jonas.adm.AdmInterface;

/**
 * JOnAS property accessor
 * @author kemlerp
 *
 */
public class JProperties {

    /**
     * Name of the JOnAS server used for tests
     */
    private static String jonasName = "jonas";

    /**
     * Initial context used for lookup
     */
    private static Context ictx = null;

    /**
     * JOnAS admin used for communicate via JMX to JOnAS
     */
    private static AdmInterface admI = null;


    /**
     * Get initialContext
     * @return the initialContext
     * @throws NamingException if the initial context can't be retrieved
     */
    private Context getInitialContext() throws NamingException {
        return new InitialContext();
    }

    /**
     * Get list environnement
     * @return JOnAS protperties
     * @throws Exception if list environnement cannot be got
     */
    public Properties getPropertiesEnv() throws Exception {
        Properties prop = null;

        try {
            if (ictx == null) {
                ictx = getInitialContext();
            }
            if (admI == null) {
                admI = (AdmInterface) ictx.lookup(jonasName + "_Adm");
            }
            prop = admI.listEnv();
        } catch (Exception e) {
            throw new Exception("Cannot get list environnement : " + e.getMessage());
        }

        return prop;
    }

    /**
     * Get services in jonas properties
     * @return A table of string with services in jonas properties
     * @throws Exception if properties cannot be got
     */
    public String[] getServices() throws Exception {
        Properties propertiesEnv = getPropertiesEnv();
        String services = propertiesEnv.getProperty("jonas.services");
        return services.split(",");
    }

    /**
     * Search a service in services
     * @param service The string that is searched
     * @return true if there is the service in services else false
     * @throws Exception if services cannot be got
     */
    public boolean searchService(String service) throws Exception {
        String[] services = getServices();
        boolean found = false;
        int i = 0;

        while (!found && i < services.length) {
            if (services[i].equals(service)) {
                found = true;
            }
            i++;
        }

        return found;
    }

    /**
     * Db in service property
     * @return True if db is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isDb() throws Exception {
        boolean exist = false;
        try {
            if (searchService("db")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Dbm in service property
     * @return True if dbm is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isDbm() throws Exception {
        boolean exist = false;
        try {
            if (searchService("dbm")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Discovery in service property
     * @return True if discovery is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isDiscovery() throws Exception {
        boolean exist = false;
        try {
            if (searchService("discovery")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Ear in service property
     * @return True if ear is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isEar() throws Exception {
        boolean exist = false;
        try {
            if (searchService("ear")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Ejb in service property
     * @return True if ejb is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isEjb() throws Exception {
        boolean exist = false;
        try {
            if (searchService("ejb")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Jms in service property
     * @return True if jms is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isJms() throws Exception {
        boolean exist = false;
        try {
            if (searchService("jms")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Jmx in service property
     * @return True if Jmx is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isJmx() throws Exception {
        boolean exist = false;
        try {
            if (searchService("jmx")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Jtm in service property
     * @return True if jtm is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isJtm() throws Exception {
        boolean exist = false;
        try {
            if (searchService("jtm")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Mail in service property
     * @return True if db is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isMail() throws Exception {
        boolean exist = false;
        try {
            if (searchService("mail")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Registry in service property
     * @return True if registry is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isRegistry() throws Exception {
        boolean exist = false;
        try {
            if (searchService("registry")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Resource in service property
     * @return True if resource is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isResource() throws Exception {
        boolean exist = false;
        try {
            if (searchService("resource")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Security in service property
     * @return True if security is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isSecurity() throws Exception {
        boolean exist = false;
        try {
            if (searchService("security")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Web in service property
     * @return True if web is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isWeb() throws Exception {
        boolean exist = false;
        try {
            if (searchService("web")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

    /**
     * Ws in service property
     * @return True if ws is a value of service property
     * @throws Exception if service property cannot be got
     */
    public boolean isWs() throws Exception {
        boolean exist = false;
        try {
            if (searchService("ws")) {
                exist = true;
            }
        } catch (Exception e) {
            throw new Exception("Cannot get services : " + e.getMessage());
        }
        return exist;
    }

}
